@@ -39,7 +39,7 @@ class EditActionDialog : public QDialog, private Ui::EditActionDialog
     Q_OBJECT
 
 public:
-    explicit EditActionDialog(Actions *actions, QWidget *parent = 0);
+    explicit EditActionDialog(Actions *actions, QWidget *parent = nullptr);
 
     bool load(qulonglong id);
 
@@ -51,7 +51,7 @@ protected slots:
     void on_dbus_method_RB_clicked(bool);
 
 protected:
-    void changeEvent(QEvent *e);
+    void changeEvent(QEvent *e) override;
 
 private:
     Actions *mActions;
