@@ -174,21 +174,38 @@
         <translation>Numatytasis</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Užverti</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="191"/>
+        <location filename="../main_window.cpp" line="194"/>
         <source>Restore Default</source>
         <translation>Atkurti numatytąjį</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="192"/>
+        <location filename="../main_window.cpp" line="195"/>
         <source>Your defined shortcuts will be removed.
 Do you want to proceed?</source>
         <translation>Jūsų apibrėžti spartieji klavišai bus pašalinti.
 Ar norite tęsti?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Platforma nepalaikoma</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt visuotiniai spartieji klavišai šiuo metu nėra prieinami „Wayland“ aplinkoje.
+
+Vietoj to, visuotiniai spartieji klavišai gali būti konfigūruojami tvarkytojo nuostatose.</translation>
+    </message>
+</context>
 </TS>
