@@ -179,12 +179,12 @@
         <translation>Zatvoriť</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="191"/>
+        <location filename="../main_window.cpp" line="194"/>
         <source>Restore Default</source>
         <translation>Vrátiť na predvolené hodnoty</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="192"/>
+        <location filename="../main_window.cpp" line="195"/>
         <source>Your defined shortcuts will be removed.
 Do you want to proceed?</source>
         <translation>Vami určené klávesové skratky budú odstránené.
@@ -196,14 +196,16 @@ Naozaj to chcete?</translation>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nepodporovaná platforma</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="52"/>
         <source>LXQt globalkeys are currently unsupported under Wayland.
 
 Global shortcuts can be configured in the settings of the compositor instead.</source>
-        <translation type="unfinished"></translation>
+        <translation>Klávesové skratky LXQt nie sú v súčasnosti v systéme Wayland podporované.
+
+Klávesové skratky je možné nakonfigurovať v nastaveniach kompozitora.</translation>
     </message>
 </context>
 </TS>
